@@ -1,9 +1,13 @@
+from typing import Any
+
 import click
 
+from ggshield.cmd.common_options import add_common_options
 from ggshield.cmd.secret.ignore import ignore_cmd
 from ggshield.cmd.secret.scan import scan_group
 
 
 @click.group(commands={"scan": scan_group, "ignore": ignore_cmd})
-def secret_group() -> None:
+@add_common_options()
+def secret_group(**kwargs: Any) -> None:
     """Commands to work with secrets."""
