@@ -1,9 +1,14 @@
 from pathlib import Path
+from typing import Any
 
 import click
 
-from ggshield.core.utils import ScanContext, ScanMode, handle_exception
-from ggshield.output import OutputHandler
+from ggshield.cmd.secret.scan.secret_scan_common_options import (
+    add_secret_scan_common_options,
+    create_output_handler,
+)
+from ggshield.core.errors import handle_exception
+from ggshield.scan import ScanContext, ScanMode
 from ggshield.scan.docker import docker_scan_archive
 
 
@@ -11,10 +16,12 @@ from ggshield.scan.docker import docker_scan_archive
 @click.argument(
     "archive", nargs=1, type=click.Path(exists=True, resolve_path=True), required=True
 )
+@add_secret_scan_common_options()
 @click.pass_context
 def docker_archive_cmd(
     ctx: click.Context,
     archive: Path,
+    **kwargs: Any,
 ) -> int:  # pragma: no cover
     """
     scan a docker archive <ARCHIVE> without attempting to save or pull the image.
@@ -22,7 +29,7 @@ def docker_archive_cmd(
     Hidden command `ggshield secret scan docker-archive`
     """
     config = ctx.obj["config"]
-    output_handler: OutputHandler = ctx.obj["output_handler"]
+    output_handler = create_output_handler(ctx)
 
     scan_context = ScanContext(
         scan_mode=ScanMode.DOCKER,
@@ -37,6 +44,7 @@ def docker_archive_cmd(
             matches_ignore=config.secret.ignored_matches,
             scan_context=scan_context,
             ignored_detectors=config.secret.ignored_detectors,
+            ignore_known_secrets=config.ignore_known_secrets,
         )
 
         return output_handler.process_scan(scan)
