@@ -1,10 +1,15 @@
 import logging
 import os
 import sys
-from typing import List, Optional, Tuple
+from typing import Any, List, Optional, Tuple
 
 import click
 
+from ggshield.cmd.secret.scan.secret_scan_common_options import (
+    add_secret_scan_common_options,
+    create_output_handler,
+)
+from ggshield.core.errors import handle_exception
 from ggshield.core.git_shell import (
     check_git_dir,
     get_list_commit_SHA,
@@ -12,13 +17,9 @@ from ggshield.core.git_shell import (
     is_valid_git_commit_ref,
 )
 from ggshield.core.text_utils import display_warning
-from ggshield.core.utils import (
-    EMPTY_SHA,
-    EMPTY_TREE,
-    ScanContext,
-    ScanMode,
-    handle_exception,
-)
+from ggshield.core.utils import EMPTY_SHA, EMPTY_TREE
+from ggshield.output.text.message import remediation_message
+from ggshield.scan import ScanContext, ScanMode
 from ggshield.scan.repo import scan_commit_range
 
 
@@ -34,10 +35,24 @@ To fix it, either edit the hook manually or make a backup of it and reinstall it
 """  # noqa: E501
 
 
+REMEDIATION_STEPS = """  Since the secret was detected before the push BUT after the commit, you need to:
+  1. rewrite the git history making sure to replace the secret with its reference (e.g. environment variable).
+  2. push again."""
+
+BYPASS_MESSAGE = """  - if you use the pre-commit framework:
+
+     SKIP=ggshield-push git push
+
+  - otherwise (warning: the following command bypasses all pre-push hooks):
+
+     git push --no-verify"""
+
+
 @click.command()
 @click.argument("prepush_args", nargs=-1, type=click.UNPROCESSED)
+@add_secret_scan_common_options()
 @click.pass_context
-def prepush_cmd(ctx: click.Context, prepush_args: List[str]) -> int:
+def prepush_cmd(ctx: click.Context, prepush_args: List[str], **kwargs: Any) -> int:
     """
     scan as a pre-push git hook.
     """
@@ -102,23 +117,35 @@ def prepush_cmd(ctx: click.Context, prepush_args: List[str]) -> int:
             command_path=ctx.command_path,
         )
 
-        return scan_commit_range(
+        return_code = scan_commit_range(
             client=ctx.obj["client"],
             cache=ctx.obj["cache"],
             commit_list=commit_list,
-            output_handler=ctx.obj["output_handler"],
+            output_handler=create_output_handler(ctx),
             exclusion_regexes=ctx.obj["exclusion_regexes"],
             matches_ignore=config.secret.ignored_matches,
             scan_context=scan_context,
             ignored_detectors=config.secret.ignored_detectors,
+            ignore_known_secrets=config.ignore_known_secrets,
         )
+        if return_code:
+            click.echo(
+                remediation_message(
+                    remediation_steps=REMEDIATION_STEPS,
+                    bypass_message=BYPASS_MESSAGE,
+                    rewrite_git_history=True,
+                ),
+                err=True,
+            )
+        return return_code
     except Exception as error:
         return handle_exception(error, config.verbose)
 
 
-def find_branch_start(commit: str, remote: str) -> str:
+def find_branch_start(commit: str, remote: str) -> Optional[str]:
     """
-    Returns the first local-only commit of the branch
+    Returns the first local-only commit of the branch.
+    Returns None if the branch does not contain any new commit.
     """
     # List all ancestors of `commit` which are not in `remote`
     # Based on _pre_push_ns() from pre-commit
@@ -136,7 +163,10 @@ def find_branch_start(commit: str, remote: str) -> str:
         ]
     )
     ancestors = output.splitlines()
-    return ancestors[0]
+
+    if ancestors:
+        return ancestors[0]
+    return None
 
 
 def collect_from_stdin(remote_name: str) -> Tuple[str, str]:
@@ -160,6 +190,8 @@ def collect_from_stdin(remote_name: str) -> Tuple[str, str]:
 
     # Pushing to a new branch
     start_commit = find_branch_start(local_commit, remote_name)
+    if start_commit is None:
+        return local_commit, local_commit
     return (local_commit, f"{start_commit}~1")
 
 
