@@ -5,17 +5,20 @@ import sys
 import tempfile
 from functools import partial
 from pathlib import Path
-from typing import Dict, List, Set
+from typing import Any, Dict, List, Set
 
 import click
 
+from ggshield.cmd.secret.scan.secret_scan_common_options import (
+    add_secret_scan_common_options,
+    create_output_handler,
+)
 from ggshield.core.config import Config
 from ggshield.core.constants import MAX_WORKERS
+from ggshield.core.errors import UnexpectedError
 from ggshield.core.file_utils import get_files_from_paths
 from ggshield.core.text_utils import create_progress_bar
-from ggshield.core.utils import ScanContext, ScanMode
-from ggshield.output import OutputHandler
-from ggshield.scan import Files, ScanCollection
+from ggshield.scan import Files, ScanCollection, ScanContext, ScanMode, SecretScanner
 
 
 PYPI_DOWNLOAD_TIMEOUT = 30
@@ -43,10 +46,10 @@ def save_package_to_tmp(temp_dir: str, package_name: str) -> None:
         click.echo("OK", err=True)
 
     except subprocess.CalledProcessError:
-        raise click.ClickException(f'Failed to download "{package_name}"')
+        raise UnexpectedError(f'Failed to download "{package_name}"')
 
     except subprocess.TimeoutExpired:
-        raise click.ClickException('Command "{}" timed out'.format(" ".join(command)))
+        raise UnexpectedError('Command "{}" timed out'.format(" ".join(command)))
 
 
 def get_files_from_package(
@@ -66,7 +69,7 @@ def get_files_from_package(
             str(archive), extract_dir=archive_dir_path, **unpack_kwargs
         )
     except Exception as exn:
-        raise click.ClickException(f'Failed to unpack package "{package_name}": {exn}.')
+        raise UnexpectedError(f'Failed to unpack package "{package_name}": {exn}.')
 
     exclusion_regexes.add(re.compile(re.escape(archive.name)))
 
@@ -82,13 +85,18 @@ def get_files_from_package(
 
 @click.command()
 @click.argument("package_name", nargs=1, type=click.STRING, required=True)
+@add_secret_scan_common_options()
 @click.pass_context
-def pypi_cmd(ctx: click.Context, package_name: str) -> int:  # pragma: no cover
+def pypi_cmd(
+    ctx: click.Context,
+    package_name: str,
+    **kwargs: Any,
+) -> int:  # pragma: no cover
     """
     scan a pypi package <NAME>.
     """
     config: Config = ctx.obj["config"]
-    output_handler: OutputHandler = ctx.obj["output_handler"]
+    output_handler = create_output_handler(ctx)
 
     with tempfile.TemporaryDirectory(suffix="ggshield") as temp_dir:
         save_package_to_tmp(temp_dir=temp_dir, package_name=package_name)
@@ -110,12 +118,16 @@ def pypi_cmd(ctx: click.Context, package_name: str) -> int:  # pragma: no cover
                 command_path=ctx.command_path,
             )
 
-            results = files.scan(
+            scanner = SecretScanner(
                 client=ctx.obj["client"],
                 cache=ctx.obj["cache"],
-                matches_ignore=config.secret.ignored_matches,
+                ignored_matches=config.secret.ignored_matches,
                 scan_context=scan_context,
                 ignored_detectors=config.secret.ignored_detectors,
+                ignore_known_secrets=config.ignore_known_secrets,
+            )
+            results = scanner.scan(
+                files.files,
                 progress_callback=partial(progress.update, task_scan),
                 scan_threads=MAX_WORKERS,
             )
