@@ -62,6 +62,10 @@ class Config:
         self.user_config.save(self._config_path)
         self.auth_config.save()
 
+    @property
+    def config_path(self) -> str:
+        return self._config_path
+
     @property
     def instance_name(self) -> str:
         """
