@@ -14,7 +14,8 @@ from oauthlib.oauth2 import OAuth2Error, WebApplicationClient
 from ggshield.core.utils import urljoin
 
 from .client import create_client, create_session
-from .config import AccountConfig, Config, InstanceConfig
+from .config import Config, InstanceConfig
+from .errors import UnexpectedError
 
 
 CLIENT_ID = "ggshield_oauth"
@@ -171,7 +172,7 @@ class OAuthClient:
             except OSError:
                 continue
         else:
-            raise click.ClickException("Could not find unoccupied port.")
+            raise UnexpectedError("Could not find unoccupied port.")
 
     def _wait_for_callback(self) -> None:
         """
@@ -187,11 +188,11 @@ class OAuthClient:
                 # the `process_callback` function
                 self.server.handle_request()  # type: ignore
         except KeyboardInterrupt:
-            raise click.ClickException("Aborting")
+            raise click.Abort()
 
         if self._handler_wrapper.error_message is not None:
             # if no error message is attached, the process is considered successful
-            raise click.ClickException(self._handler_wrapper.error_message)
+            raise UnexpectedError(self._handler_wrapper.error_message)
 
     def _get_code(self, uri: str) -> str:
         """
@@ -269,14 +270,7 @@ class OAuthClient:
         Save the new token in the configuration.
         """
         assert self._access_token is not None
-        account_config = AccountConfig(
-            workspace_id=api_token_data["account_id"],
-            token=self._access_token,
-            expire_at=api_token_data.get("expire_at"),
-            token_name=api_token_data.get("name", ""),
-            type=api_token_data.get("type", ""),
-        )
-        self.instance_config.account = account_config
+        self.instance_config.init_account(self._access_token, api_token_data)
         self.config.auth_config.save()
 
     @property
